@@ -1,22 +1,16 @@
 """
-Utilites for accessing the Captricity APIs
+Utilities for accessing the Captricity APIs
 
 NOTE: Methods which start with an underscore (_) are for internal use only and WILL change.
       Do not write your code against them.
-
 """
 import new
-import types
-import random
 import urllib
 import httplib 
 import urlparse
-import traceback
 import mimetypes
 import json
 from itertools import groupby
-from hashlib import sha256
-from urllib import urlencode
 from datetime import datetime
 
 API_TOKEN_HEADER_NAME = 'Captricity-API-Token'
@@ -24,11 +18,14 @@ API_VERSION_HEADER_NAME = 'Captricity-API-Version'
 CLIENT_VERSION = '0.01'
 USER_AGENT = 'Captricity Python Client %s' % CLIENT_VERSION
 
+
 class Client(object):
     """
     A network client for the Captricity third-party API.
-    This class will fetch the API description from the endpoint URL and dynamically create methods for accessing the API.
-    So, once you instantiate the Client you will be able to call cliend.read_job() even though you won't see that method defined below.
+    This class will fetch the API description from the endpoint URL and
+    dynamically create methods for accessing the API.
+    So, once you instantiate the Client you will be able to call client.read_job()
+    even though you won't see that method defined below.
 
     To see a list of all of the api related methods that this client offers, do the following:
     client = Client('your api token', 'http://host/api/backbone/schreddr')
@@ -44,28 +41,60 @@ class Client(object):
         self.parsed_endpoint = urlparse.urlparse(self.endpoint)
         self.api_version = version 
         schema_url = self.parsed_endpoint.path
-        if version: schema_url = schema_url + '?version=' + version
+        if version:
+            schema_url = schema_url + '?version=' + version
         self.schema = self._get_data(schema_url)
         self.api_version = self.schema['version']
 
         for resource in self.schema['resources']:
             if "GET" in resource['allowed_request_methods']:
-                read_callable = _generate_read_callable(resource['name'], resource['display_name'], resource['arguments'], resource['regex'], resource['doc'], resource['supported'])
+                read_callable = _generate_read_callable(resource['name'],
+                                                        resource['display_name'],
+                                                        resource['arguments'],
+                                                        resource['regex'],
+                                                        resource['doc'],
+                                                        resource['supported'])
                 setattr(self, read_callable.__name__, new.instancemethod(read_callable, self, self.__class__))
+
             if "PUT" in resource['allowed_request_methods']:
-                update_callable = _generate_update_callable(resource['name'], resource['display_name'], resource['arguments'], resource['regex'], resource['doc'], resource['supported'], resource['put_syntaxes'])
+                update_callable = _generate_update_callable(resource['name'],
+                                                            resource['display_name'],
+                                                            resource['arguments'],
+                                                            resource['regex'],
+                                                            resource['doc'],
+                                                            resource['supported'],
+                                                            resource['put_syntaxes'])
                 setattr(self, update_callable.__name__, new.instancemethod(update_callable, self, self.__class__))
+
             if "POST" in resource['allowed_request_methods']:
-                create_callable = _generate_create_callable(resource['name'], resource['display_name'], resource['arguments'], resource['regex'], resource['doc'], resource['supported'], resource['post_syntaxes'], resource['is_action'])
+                create_callable = _generate_create_callable(resource['name'],
+                                                            resource['display_name'],
+                                                            resource['arguments'],
+                                                            resource['regex'],
+                                                            resource['doc'],
+                                                            resource['supported'],
+                                                            resource['post_syntaxes'], resource['is_action'])
                 setattr(self, create_callable.__name__, new.instancemethod(create_callable, self, self.__class__))
+
             if "DELETE" in resource['allowed_request_methods']:
-                delete_callable = _generate_delete_callable(resource['name'], resource['display_name'], resource['arguments'], resource['regex'], resource['doc'], resource['supported'])
+                delete_callable = _generate_delete_callable(resource['name'],
+                                                            resource['display_name'],
+                                                            resource['arguments'],
+                                                            resource['regex'],
+                                                            resource['doc'],
+                                                            resource['supported'])
                 setattr(self, delete_callable.__name__, new.instancemethod(delete_callable, self, self.__class__))
 
     def print_help(self):
-        """Prints the api method info to stdout for debugging."""
+        """
+        Prints the api method info to stdout for debugging.
+        """
         keyfunc = lambda x: (x.resource_name, x.__doc__.strip())
-        resources = groupby(sorted(filter(lambda x: (hasattr(x, 'is_api_call') and x.is_api_call and x.is_supported_api), [getattr(self, resource) for resource in dir(self)]), key=keyfunc), key=keyfunc)
+        resources = groupby(sorted(filter(lambda x: (hasattr(x, 'is_api_call') and
+                                                     x.is_api_call and x.is_supported_api),
+                                          [getattr(self, resource) for resource in dir(self)]),
+                                   key=keyfunc),
+                            key=keyfunc)
         for resource_desc, resource_methods in resources:
             print resource_desc[0]
             print '\t', resource_desc[1]
@@ -77,7 +106,7 @@ class Client(object):
                     method_header += ','.join(r._get_args)
                 if r._put_or_post_args:
                     put_or_post_args = [arg['name'] for arg in reduce(lambda x, y: x+y, r._put_or_post_args.values())]
-                    method_header += ',{' +  ','.join(put_or_post_args) + '}'
+                    method_header += ',{' + ','.join(put_or_post_args) + '}'
                 method_header += ')'
                 method_desc = ""
                 if r.__name__.startswith('create'):
@@ -101,7 +130,7 @@ class Client(object):
         else:
             conn = httplib.HTTPConnection(self.parsed_endpoint.netloc)
         head = {
-            "Accept" : "application/json",
+            "Accept": "application/json",
             "User-Agent": USER_AGENT,
             API_TOKEN_HEADER_NAME: self.api_token,
         }
@@ -133,7 +162,8 @@ class Client(object):
         }
         if self.api_version in ['0.1', '0.01a']:
             head[API_VERSION_HEADER_NAME] = self.api_version
-        if accept: head['Accept'] = accept
+        if accept:
+            head['Accept'] = accept
         conn.request("GET", url, "", head)
         resp = conn.getresponse()
         self._handle_response_errors('GET', url, resp)
@@ -170,7 +200,8 @@ class Client(object):
         h.endheaders()
         h.send(body)
         errcode, errmsg, headers = h.getreply()
-        if errcode not in [200, 202]: raise IOError('Response to %s to URL %s was status code %s: %s' % (method, url, errcode, h.file.read()))
+        if errcode not in [200, 202]:
+            raise IOError('Response to %s to URL %s was status code %s: %s' % (method, url, errcode, h.file.read()))
         return json.loads(h.file.read())
 
     def _put_or_post_json(self, method, url, data):
@@ -183,8 +214,8 @@ class Client(object):
         else:
             conn = httplib.HTTPConnection(self.parsed_endpoint.netloc)
         head = {
-            "Content-Type" : "application/json",
-            "Accept" : "application/json",
+            "Content-Type": "application/json",
+            "Accept": "application/json",
             "User-Agent": USER_AGENT,
             API_TOKEN_HEADER_NAME: self.api_token,
         }
@@ -198,15 +229,16 @@ class Client(object):
     def _generate_url(self, regex, arguments):
         """
         Uses the regex (of the type defined in Django's url patterns) and the arguments to return a relative URL
-        For example, if the regex is '^/api/shreddr/job/(?P<id>[\d]+)$' and arguments is ['23'] then return would be '/api/shreddr/job/23'
+        For example, if the regex is '^/api/shreddr/job/(?P<id>[\d]+)$' and arguments is ['23']
+        then return would be '/api/shreddr/job/23'
         """
         regex_tokens = _split_regex(regex)
         result = ''
         for i in range(len(arguments)):
             result = result + str(regex_tokens[i]) + str(arguments[i])
-        if len(regex_tokens) > len(arguments): result += regex_tokens[-1]
+        if len(regex_tokens) > len(arguments):
+            result += regex_tokens[-1]
         return result
-        #return '%s://%s/%s' % (self.parsed_endpoint.scheme, self.parsed_endpoint.netloc, result)
 
     def _handle_response_errors(self, method, url, response):
         if response.status in [200, 202]:
@@ -215,28 +247,33 @@ class Client(object):
                        method, url, response.status, response.read()))
 
     def read_example_job(self):
-        '''
+        """
         Convenience method for pulling out the example job.  Used in the
         Captricity API Quickstart.
-        '''
+        """
         for job in self.read_jobs():
             if job['is_example']:
                 return job
 
     def launch_job(self, job_id):
-        '''
+        """
         Convenience method for launching a job.  We use POST for actions
         outside of HTTP verbs (job launch in this case).
-        '''
-        assert self.api_version.lower() in ['0.01a', '0.1'], 'This method is only supported in BETA (0.01) and ALPHA (0.01a) versions'
+        """
+        assert self.api_version.lower() in ['0.01a', '0.1'], \
+            'This method is only supported in BETA (0.01) and ALPHA (0.01a) versions'
         try:
-            self.create_job(job_id, {'submit_job_action':True})
+            self.create_job(job_id, {'submit_job_action': True})
         except ValueError:
             pass
         return self.read_job(job_id)
 
+
 def parse_date_string(date_string):
-    """Converts the date strings created by the API (e.g. '2012-04-06T19:11:33.032') and returns an equivalent datetime instance."""
+    """
+    Converts the date strings created by the API (e.g. '2012-04-06T19:11:33.032') and
+    returns an equivalent datetime instance.
+    """
     return datetime.strptime(date_string, "%Y-%m-%dT%H:%M:%S.%f")
 
 
@@ -268,15 +305,22 @@ def _encode_multipart_formdata(fields, files):
     content_type = 'multipart/form-data; boundary=%s' % BOUNDARY
     return content_type, body
 
+
 def get_content_type(filename):
-    """Use the python mimetypes to determine a mime type, or return application/octet-stream"""
+    """
+    Use the python mimetypes to determine a mime type, or return application/octet-stream
+    """
     return mimetypes.guess_type(filename)[0] or 'application/octet-stream'
 
+
 def _generate_read_callable(name, display_name, arguments, regex, doc, supported):
-    """Returns a callable which conjures the URL for the resource and GETs a response"""
+    """
+    Returns a callable which conjures the URL for the resource and GETs a response
+    """
     def f(self, *args, **kwargs):
         url = self._generate_url(regex, args)
-        if 'params' in kwargs: url += "?" + urllib.urlencode(kwargs['params'])
+        if 'params' in kwargs:
+            url += "?" + urllib.urlencode(kwargs['params'])
         return self._get_data(url, accept=(kwargs.get('accept')))
     f.__name__ = str('read_%s' % name)
     f.__doc__ = doc
@@ -288,8 +332,11 @@ def _generate_read_callable(name, display_name, arguments, regex, doc, supported
     f.is_supported_api = supported
     return f
 
+
 def _generate_update_callable(name, display_name, arguments, regex, doc, supported, put_arguments):
-    """Returns a callable which conjures the URL for the resource and PUTs data"""
+    """
+    Returns a callable which conjures the URL for the resource and PUTs data
+    """
     def f(self, *args, **kwargs):
         for key, value in args[-1].items():
             if type(value) == file:
@@ -305,8 +352,11 @@ def _generate_update_callable(name, display_name, arguments, regex, doc, support
     f.is_supported_api = supported
     return f
 
+
 def _generate_create_callable(name, display_name, arguments, regex, doc, supported, post_arguments, is_action):
-    """Returns a callable which conjures the URL for the resource and POSTs data"""
+    """
+    Returns a callable which conjures the URL for the resource and POSTs data
+    """
     def f(self, *args, **kwargs):
         for key, value in args[-1].items():
             if type(value) == file:
@@ -325,6 +375,7 @@ def _generate_create_callable(name, display_name, arguments, regex, doc, support
     f.is_supported_api = supported
     return f
 
+
 def _generate_delete_callable(name, display_name, arguments, regex, doc, supported):
     def f(self, *args, **kwargs):
         return self._delete_resource(self._generate_url(regex, args))
@@ -338,13 +389,16 @@ def _generate_delete_callable(name, display_name, arguments, regex, doc, support
     f.is_supported_api = supported
     return f
 
+
 def _split_regex(regex):
     """
     Return an array of the URL split at each regex match like (?P<id>[\d]+)
     Call with a regex of '^/foo/(?P<id>[\d]+)/bar/$' and you will receive ['/foo/', '/bar/']
     """
-    if regex[0] == '^': regex = regex[1:]
-    if regex[-1] == '$': regex = regex[0:-1]
+    if regex[0] == '^':
+        regex = regex[1:]
+    if regex[-1] == '$':
+        regex = regex[0:-1]
     results = []
     line = ''
     for c in regex:
@@ -355,5 +409,6 @@ def _split_regex(regex):
             line = ''
         else:
             line = line + c
-    if len(line) > 0: results.append(line)
+    if len(line) > 0:
+        results.append(line)
     return results
