@@ -2,6 +2,7 @@ import os
 from urllib import urlencode
 from hashlib import sha256
 
+
 def generate_request_access_signature(parameters, secret_key):
     """
     Generate the parameter signature used during third party access requests
@@ -13,7 +14,7 @@ def generate_request_access_signature(parameters, secret_key):
     keys.sort()
 
     # create an array of url encoded key:value pairs
-    encoded_pairs = [urlencode({key:parameters[key]}) for key in keys] 
+    encoded_pairs = [urlencode({key: parameters[key]}) for key in keys]
 
     # create the serialized parameters in a single, URL style string
     serialized_parameters = '&'.join(encoded_pairs)
@@ -25,7 +26,6 @@ def generate_request_access_signature(parameters, secret_key):
     return sha256(string_to_hash).hexdigest()
 
 _example_form_image_paths = ['page1.png', 'page2.png']
-_example_form_image_paths = map(
-        lambda x: os.path.join(os.path.dirname(__file__), 'img', x),
-        _example_form_image_paths)
+_example_form_image_paths = map(lambda x: os.path.join(os.path.dirname(__file__), 'img', x),
+                                _example_form_image_paths)
 example_form_image_paths = map(lambda x: os.path.abspath(x), _example_form_image_paths)
